#!/bin/sh
#
# check_user_mem - Nagios plugin warns if a user consumes too much memory
# RSS is better than VSZ because the Linux kernel does not limit overcommitment,
# and this is (mis)used by (Java-)applications.
# ARG1: warning level
#
# by Michael Tosch
#
# returns only OK or WARNING

set -f
export PATH
PATH=/bin:/usr/bin:/usr/sbin:/sbin

print_usage(){
  echo "Usage: $0 [MB memory]"
}

limit=${1:-5700}
case $limit in
*-h*) echo "This plugin warns if a user consumes too much memory (RSS)
"; print_usage; exit 3;;
*[!0-9]*) print_usage; exit 3;;
esac

# Solaris zone awareness
if [ "`{ /sbin/zonename; } 2>/dev/null`" = "global" ]
then
  scope="-z global"
else
  scope="-e"
fi

check=`ps $scope -o uid= -o rss= | awk '
BEGIN {limit='$limit'*1024}
{m[$1]+=$2} END {for (i in m) if (m[i]>max) {max=m[i]; uid=i} if (max>limit) print "uid="uid,"max="int(max/1024)}
'`
if [ -z "$check" ]
then
  echo "OK: all users below $limit MB resident memory"
  exit 0
else
  eval $check
  user=`getent passwd $uid | cut -f1 -d:`
  echo "WARNING: user $user ($uid) uses $max MB resident memory"
  exit 1
fi
